@@ -1,23 +1,22 @@
 import os
 import sys
-
-import qdarkstyle
-from PyQt5 import QtCore
-
 import sip
+from PyQt5 import QtCore
+from PyQt5.QtWidgets import QMessageBox
+
+from vorta.borg.create import BorgCreateThread
 from vorta.borg.version import BorgVersionThread
-from vorta.config import STATE_DIR
+from vorta.config import TEMP_DIR
+from vorta.i18n import init_translations, translate
+from vorta.models import BackupProfileModel, SettingsModel
+from vorta.qt_single_application import QtSingleApplication
+from vorta.scheduler import VortaScheduler
+from vorta.tray_menu import TrayMenu
+from vorta.utils import borg_compat, parse_args
+from vorta.views.main_window import MainWindow
+from vorta.notifications import VortaNotifications
 
-from .borg.create import BorgCreateThread
-from .i18n import init_translations, translate
-from .models import BackupProfileModel, SettingsModel
-from .qt_single_application import QtSingleApplication
-from .scheduler import VortaScheduler
-from .tray_menu import TrayMenu
-from .utils import borg_compat, parse_args, set_tray_icon
-from .views.main_window import MainWindow
-
-APP_ID = os.path.join(STATE_DIR, "socket")
+APP_ID = os.path.join(TEMP_DIR, "socket")
 
 
 class VortaApp(QtSingleApplication):
@@ -32,6 +31,7 @@ class VortaApp(QtSingleApplication):
     backup_finished_event = QtCore.pyqtSignal(dict)
     backup_cancelled_event = QtCore.pyqtSignal()
     backup_log_event = QtCore.pyqtSignal(str)
+    backup_progress_event = QtCore.pyqtSignal(str)
 
     def __init__(self, args_raw, single_app=False):
 
@@ -49,10 +49,6 @@ class VortaApp(QtSingleApplication):
         # Prepare system tray icon
         self.tray = TrayMenu(self)
 
-        # Apply dark stylesheet
-        if SettingsModel.get(key='use_dark_theme').value:
-            self.setStyleSheet(qdarkstyle.load_stylesheet_pyqt5())
-
         args = parse_args()
         if getattr(args, 'daemonize', False):
             pass
@@ -64,6 +60,17 @@ class VortaApp(QtSingleApplication):
         self.backup_cancelled_event.connect(self.backup_cancelled_event_response)
         self.message_received_event.connect(self.message_received_event_response)
         self.set_borg_details_action()
+        self.installEventFilter(self)
+
+    def eventFilter(self, source, event):
+        if event.type() == QtCore.QEvent.ApplicationPaletteChange and type(source) == MainWindow:
+            self.main_window.set_icons()
+            self.main_window.repoTab.set_icons()
+            self.main_window.archiveTab.set_icons()
+            self.main_window.scheduleTab.set_icons()
+        if event.type() == QtCore.QEvent.ApplicationPaletteChange and source == self.tray.contextMenu():
+            self.tray.set_tray_icon()
+        return False
 
     def create_backup_action(self, profile_id=None):
         if not profile_id:
@@ -75,7 +82,9 @@ class VortaApp(QtSingleApplication):
             thread = BorgCreateThread(msg['cmd'], msg, parent=self)
             thread.start()
         else:
-            self.backup_log_event.emit(translate('messages', msg['message']))
+            notifier = VortaNotifications.pick()
+            notifier.deliver(self.tr('Vorta Backup'), translate('messages', msg['message']), level='error')
+            self.backup_progress_event.emit(translate('messages', msg['message']))
 
     def open_main_window_action(self):
         self.main_window = MainWindow(self)
@@ -92,13 +101,13 @@ class VortaApp(QtSingleApplication):
             self.open_main_window_action()
 
     def backup_started_event_response(self):
-        set_tray_icon(self.tray, active=True)
+        self.tray.set_tray_icon(active=True)
 
     def backup_finished_event_response(self):
-        set_tray_icon(self.tray)
+        self.tray.set_tray_icon()
 
     def backup_cancelled_event_response(self):
-        set_tray_icon(self.tray)
+        self.tray.set_tray_icon()
 
     def message_received_event_response(self, message):
         if message == "open main window":
@@ -107,13 +116,29 @@ class VortaApp(QtSingleApplication):
     def set_borg_details_action(self):
         params = BorgVersionThread.prepare()
         if not params['ok']:
+            self._alert_missing_borg()
             return
         thread = BorgVersionThread(params['cmd'], params, parent=self)
         thread.result.connect(self.set_borg_details_result)
         thread.start()
 
     def set_borg_details_result(self, result):
-        borg_compat.set_version(result['data']['version'], result['data']['path'])
-        if self._main_window_exists():
-            self.main_window.miscTab.set_borg_details(borg_compat.version, borg_compat.path)
-            self.main_window.repoTab.toggle_available_compression()
+        """
+        Receive result from BorgVersionThread. If MainWindow is open, set the version in misc tab.
+        If no valid version was found, display an error.
+        """
+        if 'version' in result['data']:
+            borg_compat.set_version(result['data']['version'], result['data']['path'])
+            if self._main_window_exists():
+                self.main_window.miscTab.set_borg_details(borg_compat.version, borg_compat.path)
+                self.main_window.repoTab.toggle_available_compression()
+        else:
+            self._alert_missing_borg()
+
+    def _alert_missing_borg(self):
+        msg = QMessageBox()
+        msg.setIcon(QMessageBox.Critical)
+        msg.setText(self.tr("No Borg Binary Found"))
+        msg.setInformativeText(self.tr("Vorta was unable to locate a usable Borg Backup binary."))
+        msg.setStandardButtons(QMessageBox.Ok)
+        msg.exec_()
