@@ -13,7 +13,7 @@ from subprocess import Popen, PIPE
 
 from vorta.i18n import trans_late
 from vorta.models import EventLogModel, BackupProfileMixin
-from vorta.utils import keyring, borg_compat
+from vorta.utils import keyring, borg_compat, pretty_bytes
 from vorta.keyring.db import VortaDBKeyring
 
 mutex = QtCore.QMutex()
@@ -195,15 +195,23 @@ class BorgThread(QtCore.QThread, BackupProfileMixin):
                     try:
                         parsed = json.loads(line)
                         if parsed['type'] == 'log_message':
-                            self.log_event(f'{parsed["levelname"]}: {parsed["message"]}')
+                            self.app.backup_log_event.emit(f'{parsed["levelname"]}: {parsed["message"]}')
                             level_int = getattr(logging, parsed["levelname"])
                             logger.log(level_int, parsed["message"])
                         elif parsed['type'] == 'file_status':
-                            self.log_event(f'{parsed["path"]} ({parsed["status"]})')
+                            self.app.backup_log_event.emit(f'{parsed["path"]} ({parsed["status"]})')
+                        elif parsed['type'] == 'archive_progress':
+                            msg = (
+                                f"Files: {parsed['nfiles']}, "
+                                f"Original: {pretty_bytes(parsed['original_size'])}, "
+                                f"Deduplicated: {pretty_bytes(parsed['deduplicated_size'])}, "
+                                f"Compressed: {pretty_bytes(parsed['compressed_size'])}"
+                            )
+                            self.app.backup_progress_event.emit(msg)
                     except json.decoder.JSONDecodeError:
                         msg = line.strip()
                         if msg:  # Log only if there is something to log.
-                            self.log_event(msg)
+                            self.app.backup_log_event.emit(msg)
                             logger.warning(msg)
 
             if p.poll() is not None:
@@ -240,9 +248,6 @@ class BorgThread(QtCore.QThread, BackupProfileMixin):
     def process_result(self, result):
         pass
 
-    def log_event(self, msg):
-        self.updated.emit(msg)
-
     def started_event(self):
         self.updated.emit(self.tr('Task started'))
 
