@@ -3,12 +3,9 @@ from .borg_thread import BorgThread
 
 class BorgCheckThread(BorgThread):
 
-    def log_event(self, msg):
-        self.app.backup_log_event.emit(msg)
-
     def started_event(self):
         self.app.backup_started_event.emit()
-        self.app.backup_log_event.emit(self.tr('Starting consistency check...'))
+        self.app.backup_progress_event.emit(self.tr('Starting consistency check...'))
 
     def finished_event(self, result):
         self.app.backup_finished_event.emit(result)
