@@ -4,12 +4,9 @@ import getpass
 import operator
 import os
 import platform
-import plistlib
 import re
-import subprocess
 import sys
 import unicodedata
-import xml
 from collections import defaultdict
 from datetime import datetime as dt
 from functools import reduce
@@ -20,22 +17,32 @@ from paramiko.ecdsakey import ECDSAKey
 from paramiko.ed25519key import Ed25519Key
 from paramiko.rsakey import RSAKey
 from PyQt5 import QtCore
-from PyQt5.QtGui import QIcon
 from PyQt5.QtWidgets import QApplication, QFileDialog, QSystemTrayIcon
 
 from vorta.borg._compatibility import BorgCompatibility
 from vorta.keyring.abc import VortaKeyring
 from vorta.log import logger
+from vorta.network_status.abc import NetworkStatusMonitor
 
 QApplication.setAttribute(QtCore.Qt.AA_EnableHighDpiScaling, True)  # enable highdpi scaling
 QApplication.setAttribute(QtCore.Qt.AA_UseHighDpiPixmaps, True)  # use highdpi icons
 
 keyring = VortaKeyring.get_keyring()
 logger.info('Using %s Keyring implementation.', keyring.__class__.__name__)
-
 borg_compat = BorgCompatibility()
 
 
+_network_status_monitor = None
+
+
+def get_network_status_monitor():
+    global _network_status_monitor
+    if _network_status_monitor is None:
+        _network_status_monitor = NetworkStatusMonitor.get_network_status_monitor()
+        logger.info('Using %s NetworkStatusMonitor implementation.', _network_status_monitor.__class__.__name__)
+    return _network_status_monitor
+
+
 def nested_dict():
     """
     Combination of two idioms to quickly build dicts from lists of keys:
@@ -55,7 +62,7 @@ def choose_file_dialog(parent, title, want_folder=True):
     if want_folder:
         options |= QFileDialog.ShowDirsOnly
     dialog = QFileDialog(parent, title, os.path.expanduser('~'), options=options)
-    dialog.setFileMode(QFileDialog.Directory if want_folder else QFileDialog.AnyFile)
+    dialog.setFileMode(QFileDialog.Directory if want_folder else QFileDialog.ExistingFiles)
     dialog.setParent(parent, QtCore.Qt.Sheet)
     return dialog
 
@@ -128,63 +135,33 @@ def get_sorted_wifis(profile):
 
     from vorta.models import WifiSettingModel
 
-    if sys.platform == 'darwin':
-        plist_path = '/Library/Preferences/SystemConfiguration/com.apple.airport.preferences.plist'
+    system_wifis = get_network_status_monitor().get_known_wifis()
+    if system_wifis is None:
+        # Don't show any networks if we can't get the current list
+        return []
 
-        try:
-            plist_file = open(plist_path, 'rb')
-            wifis = plistlib.load(plist_file).get('KnownNetworks')
-        except xml.parsers.expat.ExpatError:
-            logger.error('Unable to parse list of Wifi networks.')
-            return []
+    for wifi in system_wifis:
+        db_wifi, created = WifiSettingModel.get_or_create(
+            ssid=wifi.ssid,
+            profile=profile.id,
+            defaults={'last_connected': wifi.last_connected, 'allowed': True}
+        )
 
-        if wifis is not None:
-            for wifi in wifis.values():
-                timestamp = wifi.get('LastConnected', None)
-                ssid = wifi.get('SSIDString', None)
+        # update last connected time
+        if not created and db_wifi.last_connected != wifi.last_connected:
+            db_wifi.last_connected = wifi.last_connected
+            db_wifi.save()
 
-                if ssid is None:
-                    continue
-
-                db_wifi, created = WifiSettingModel.get_or_create(
-                    ssid=ssid,
-                    profile=profile.id,
-                    defaults={'last_connected': timestamp, 'allowed': True}
-                )
-
-                # update last connected time
-                if not created and db_wifi.last_connected != timestamp:
-                    db_wifi.last_connected = timestamp
-                    db_wifi.save()
-
-            # remove Wifis that were deleted in the system.
-            deleted_wifis = WifiSettingModel.select() \
-                .where(WifiSettingModel.ssid.not_in([w['SSIDString'] for w in wifis.values()]))
-            for wifi in deleted_wifis:
-                wifi.delete_instance()
+    # remove Wifis that were deleted in the system.
+    deleted_wifis = WifiSettingModel.select() \
+        .where(WifiSettingModel.ssid.not_in([wifi.ssid for wifi in system_wifis]))
+    for wifi in deleted_wifis:
+        wifi.delete_instance()
 
     return WifiSettingModel.select() \
         .where(WifiSettingModel.profile == profile.id).order_by(-WifiSettingModel.last_connected)
 
 
-def get_current_wifi():
-    """
-    Get current SSID or None if Wifi is off.
-
-    From https://gist.github.com/keithweaver/00edf356e8194b89ed8d3b7bbead000c
-    """
-
-    if sys.platform == 'darwin':
-        cmd = ['/System/Library/PrivateFrameworks/Apple80211.framework/Versions/Current/Resources/airport', '-I']
-        process = subprocess.Popen(cmd, stdout=subprocess.PIPE)
-        out, err = process.communicate()
-        process.wait()
-        for line in out.decode("utf-8").split('\n'):
-            split_line = line.strip().split(':')
-            if split_line[0] == 'SSID':
-                return split_line[1].strip()
-
-
 def parse_args():
     parser = argparse.ArgumentParser(description='Vorta Backup GUI for Borg.')
     parser.add_argument('--version', '-V',
@@ -210,25 +187,12 @@ def slugify(value):
     return re.sub(r'[-\s]+', '-', value)
 
 
-def set_tray_icon(tray, active=False):
-    from vorta.models import SettingsModel
-    use_light_style = SettingsModel.get(key='use_light_icon').value
-    icon_name = f"icons/hdd-o{'-active' if active else ''}-{'light' if use_light_style else 'dark'}.png"
-    icon = QIcon(get_asset(icon_name))
-    tray.setIcon(icon)
-
-
 def uses_dark_mode():
     """
     This function detects if we are running in dark mode (e.g. macOS dark mode).
-
-    Returns None if the interface style cannot be determined, otherwise a boolean.
     """
-    if sys.platform == 'darwin':
-        from Foundation import NSUserDefaults
-        stdud = NSUserDefaults.standardUserDefaults()
-        return stdud.stringForKey_("AppleInterfaceStyle") == "Dark"
-    return None
+    palette = QApplication.instance().palette()
+    return palette.windowText().color().lightness() > palette.window().color().lightness()
 
 
 def format_archive_name(profile, archive_name_tpl):
