@@ -1,5 +1,3 @@
-import sys
-
 from PyQt5 import QtCore, uic
 from PyQt5.QtWidgets import QShortcut, QMessageBox
 from PyQt5.QtGui import QKeySequence
@@ -7,8 +5,9 @@ from PyQt5.QtGui import QKeySequence
 from vorta.borg.borg_thread import BorgThread
 from vorta.i18n import trans_late
 from vorta.models import BackupProfileModel, SettingsModel
-from vorta.utils import borg_compat, get_asset, is_system_tray_available
-from vorta.views.utils import get_theme_class
+from vorta.utils import borg_compat, get_asset, is_system_tray_available, get_network_status_monitor
+from vorta.views.utils import get_colored_icon
+from vorta.views.partials.loading_button import LoadingButton
 
 from .archive_tab import ArchiveTab
 from .misc_tab import MiscTab
@@ -18,7 +17,7 @@ from .schedule_tab import ScheduleTab
 from .source_tab import SourceTab
 
 uifile = get_asset('UI/mainwindow.ui')
-MainWindowUI, MainWindowBase = uic.loadUiType(uifile, from_imports=True, import_from=get_theme_class())
+MainWindowUI, MainWindowBase = uic.loadUiType(uifile)
 
 
 class MainWindow(MainWindowBase, MainWindowUI):
@@ -28,22 +27,21 @@ class MainWindow(MainWindowBase, MainWindowUI):
         self.setWindowTitle('Vorta for Borg Backup')
         self.setAttribute(QtCore.Qt.WA_DeleteOnClose, True)
         self.app = parent
-        self.current_profile = BackupProfileModel.select().order_by('id').first()
         self.setWindowFlags(QtCore.Qt.WindowCloseButtonHint | QtCore.Qt.WindowMinimizeButtonHint)
+        self.createStartBtn = LoadingButton(self.tr("Start Backup"))
+        self.gridLayout.addWidget(self.createStartBtn, 0, 0, 1, 1)
+        self.createStartBtn.setGif(get_asset("icons/loading"))
 
-        # Temporary fix for QT Darkstyle dropdown issue.
-        # See https://github.com/ColinDuquesnoy/QDarkStyleSheet/issues/200
-        if SettingsModel.get(key='use_dark_theme').value:
-            self.setStyleSheet("""
-            QComboBox::item:checked {
-            height: 12px;
-            border: 1px solid #32414B;
-            margin-top: 0px;
-            margin-bottom: 0px;
-            padding: 4px;
-            padding-left: 0px;
-            }
-            """)
+        # Use previous window state
+        previous_window_width = SettingsModel.get(key='previous_window_width')
+        previous_window_height = SettingsModel.get(key='previous_window_height')
+        self.resize(int(previous_window_width.str_value), int(previous_window_height.str_value))
+
+        # Select previously used profile, if available
+        prev_profile_id = SettingsModel.get(key='previous_profile_id')
+        self.current_profile = BackupProfileModel.get_or_none(id=prev_profile_id.str_value)
+        if self.current_profile is None:
+            self.current_profile = BackupProfileModel.select().order_by('name').first()
 
         # Load tab models
         self.repoTab = RepoTab(self.repoTabSlot)
@@ -66,20 +64,22 @@ class MainWindow(MainWindowBase, MainWindowUI):
 
         self.app.backup_started_event.connect(self.backup_started_event)
         self.app.backup_finished_event.connect(self.backup_finished_event)
-        self.app.backup_log_event.connect(self.set_status)
+        self.app.backup_log_event.connect(self.set_log)
+        self.app.backup_progress_event.connect(self.set_progress)
         self.app.backup_cancelled_event.connect(self.backup_cancelled_event)
 
         # Init profile list
-        for profile in BackupProfileModel.select():
+        for profile in BackupProfileModel.select().order_by(BackupProfileModel.name):
             self.profileSelector.addItem(profile.name, profile.id)
-        self.profileSelector.setCurrentIndex(0)
+        current_profile_index = self.profileSelector.findData(self.current_profile.id)
+        self.profileSelector.setCurrentIndex(current_profile_index)
         self.profileSelector.currentIndexChanged.connect(self.profile_select_action)
         self.profileRenameButton.clicked.connect(self.profile_rename_action)
         self.profileDeleteButton.clicked.connect(self.profile_delete_action)
         self.profileAddButton.clicked.connect(self.profile_add_action)
 
         # OS-specific startup options:
-        if sys.platform != 'darwin':
+        if not get_network_status_monitor().is_network_status_available():
             # Hide Wifi-rule section in schedule tab.
             self.scheduleTab.wifiListLabel.hide()
             self.scheduleTab.wifiListWidget.hide()
@@ -89,20 +89,32 @@ class MainWindow(MainWindowBase, MainWindowUI):
         # Connect to existing thread.
         if BorgThread.is_running():
             self.createStartBtn.setEnabled(False)
+            self.createStartBtn.start()
             self.cancelButton.setEnabled(True)
-            self.set_status(self.tr('Backup in progress.'), progress_max=0)
+
+        self.set_icons()
 
     def on_close_window(self):
         self.close()
 
-    def set_status(self, text=None, progress_max=None):
-        if text:
-            self.createProgressText.setText(text)
-        if progress_max is not None:
-            self.createProgress.setRange(0, progress_max)
-        self.createProgressText.repaint()
+    def set_icons(self):
+        self.profileAddButton.setIcon(get_colored_icon('plus'))
+        self.profileRenameButton.setIcon(get_colored_icon('edit'))
+        self.profileDeleteButton.setIcon(get_colored_icon('trash'))
+
+    def set_progress(self, text=''):
+        self.progressText.setText(text)
+        self.progressText.repaint()
+
+    def set_log(self, text=''):
+        self.logText.setText(text)
+        self.logText.repaint()
 
     def _toggle_buttons(self, create_enabled=True):
+        if create_enabled:
+            self.createStartBtn.stop()
+        else:
+            self.createStartBtn.start()
         self.createStartBtn.setEnabled(create_enabled)
         self.createStartBtn.repaint()
         self.cancelButton.setEnabled(not create_enabled)
@@ -114,13 +126,16 @@ class MainWindow(MainWindowBase, MainWindowUI):
         self.repoTab.populate_from_profile()
         self.sourceTab.populate_from_profile()
         self.scheduleTab.populate_from_profile()
+        SettingsModel.update({SettingsModel.str_value: self.current_profile.id})\
+            .where(SettingsModel.key == 'previous_profile_id')\
+            .execute()
 
     def profile_rename_action(self):
         window = EditProfileWindow(rename_existing_id=self.profileSelector.currentData())
         window.setParent(self, QtCore.Qt.Sheet)
         window.show()
         if window.exec_():
-            self.profileSelector.setItemText(self.profileSelector.currentIndex(), window.edited_profile.name)
+            self.profileSelector.setItemText(self.profileSelector.currentIndex(), window.profileNameField.text())
 
     def profile_delete_action(self):
         if self.profileSelector.count() > 1:
@@ -144,28 +159,34 @@ class MainWindow(MainWindowBase, MainWindowUI):
         window = AddProfileWindow()
         window.setParent(self, QtCore.Qt.Sheet)
         window.show()
-        if window.exec_() and window.edited_profile:
+        if window.exec_():
             self.profileSelector.addItem(window.edited_profile.name, window.edited_profile.id)
             self.profileSelector.setCurrentIndex(self.profileSelector.count() - 1)
         else:
             self.profileSelector.setCurrentIndex(self.profileSelector.currentIndex())
 
     def backup_started_event(self):
-        self.set_status(progress_max=0)
         self._toggle_buttons(create_enabled=False)
+        self.set_log('')
 
     def backup_finished_event(self):
-        self.set_status(progress_max=100)
         self._toggle_buttons(create_enabled=True)
         self.archiveTab.populate_from_profile()
         self.repoTab.init_repo_stats()
 
     def backup_cancelled_event(self):
         self._toggle_buttons(create_enabled=True)
-        self.set_status(progress_max=100)
-        self.set_status(self.tr('Task cancelled'))
+        self.set_log(self.tr('Task cancelled'))
 
     def closeEvent(self, event):
+        # Save window state in SettingsModel
+        SettingsModel.update({SettingsModel.str_value: str(self.frameGeometry().width())})\
+            .where(SettingsModel.key == 'previous_window_width')\
+            .execute()
+        SettingsModel.update({SettingsModel.str_value: str(self.frameGeometry().height())})\
+            .where(SettingsModel.key == 'previous_window_height')\
+            .execute()
+
         if not is_system_tray_available():
             run_in_background = QMessageBox.question(self,
                                                      trans_late("MainWindow QMessagebox",
